@@ -860,7 +860,6 @@ class Pinterest:
 
         url = self.req_builder.buildGet(url=CONVERSATION_RESOURCE, options=options)
         response = self.get(url=url).json()
-
         next_bookmark = response['resource']['options']['bookmarks'][0]
         self.bookmark_manager.add_bookmark(primary='conversations', bookmark=next_bookmark)
 
@@ -880,37 +879,59 @@ class Pinterest:
         data = self.req_builder.buildPost(options=options)
         return self.post(url=BOARD_SECTION_RESOURCE, data=data)
 
-    def get_board_sections(self, board_id=''):
+
+    def get_board_sections(self, board_id='', reset_bookmark=False):
         """
         Obtains a list of all sections of a board
         """
+        next_bookmark = self.bookmark_manager.get_bookmark(primary='board_sections', secondary=board_id)
+        if next_bookmark == '-end-':
+            if reset_bookmark:
+                self.bookmark_manager.reset_bookmark(primary='board_sections', secondary=board_id)
+            return []
+
         options = {
             "isPrefetch": False,
             "board_id": board_id,
-            "redux_normalize_feed": True
+            "redux_normalize_feed": True,
+            "bookmarks": [next_bookmark]
         }
 
         url = self.req_builder.buildGet(url=GET_BOARD_SECTIONS, options=options)
         response = self.get(url=url).json()
+        bookmark = response['resource']['options']['bookmarks'][0]
+        self.bookmark_manager.add_bookmark(primary='board_sections', secondary=board_id, bookmark=bookmark)
+
         return response['resource_response']['data']
 
-    def get_section_pins(self, section_id='', page_size=250):
+
+    def get_section_pins(self, section_id='', page_size=250, reset_bookmark=False):
         """
         Returns a list of all pins in a board section.
         This method is batched meaning in order to obtain all pins in the section
         you need to call is until empty list is returned
         """
+        next_bookmark = self.bookmark_manager.get_bookmark(primary='section_pins', secondary=section_id)
+        if next_bookmark == '-end-':
+            if reset_bookmark:
+                self.bookmark_manager.reset_bookmark(primary='section_pins', secondary=section_id)
+            return []
+
         options = {
             "isPrefetch": False,
             "field_set_key": "react_grid_pin",
             "is_own_profile_pins": True,
             "page_size": page_size,
             "redux_normalize_feed": True,
-            "section_id": section_id
+            "section_id": section_id,
+            "bookmarks": [next_bookmark]
         }
 
         url = self.req_builder.buildGet(url=GET_BOARD_SECTION_PINS, options=options)
         response = self.get(url=url).json()
+        bookmark = response['resource']['options']['bookmarks'][0]
+        self.bookmark_manager.add_bookmark(primary='section_pins', secondary=section_id, bookmark=bookmark)
+
         data = response['resource_response']['data']
         pins = []
 
@@ -919,6 +940,7 @@ class Pinterest:
                 pins.append(d)
         return pins
 
+
     def delete_board_section(self, section_id=''):
         """
         Deletes a board section by id
